# Generated by Django 3.1.2 on 2020-10-15 15:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("sections_app", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="customcontent",
            name="content_url",
            field=models.URLField(blank=True, null=True, verbose_name="content url"),
        ),
        migrations.AddField(
            model_name="customcontent",
            name="img",
            field=models.URLField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="customcontent",
            name="name",
            field=models.CharField(blank=True, max_length=255, verbose_name="name"),
        ),
        migrations.AddField(
            model_name="customcontent",
            name="redirect_url",
            field=models.URLField(blank=True, null=True, verbose_name="redirect url"),
        ),
    ]
